@@ -2,11 +2,12 @@
 
 from hashlib import sha1
 from base64 import urlsafe_b64encode, urlsafe_b64decode
-
+from datetime import datetime
 from .compat import b, s
 
 try:
     import zlib
+
     binascii = zlib
 except ImportError:
     zlib = None
@@ -19,7 +20,7 @@ def urlsafe_base64_encode(data):
     """urlsafe的base64编码:
 
     对提供的数据进行urlsafe的base64编码。规格参考：
-    http://developer.qiniu.com/docs/v6/api/overview/appendix.html#urlsafe-base64
+    https://developer.qiniu.com/kodo/manual/1231/appendix#1
 
     Args:
         data: 待编码的数据，一般为字符串
@@ -108,7 +109,7 @@ def _sha1(data):
 def etag_stream(input_stream):
     """计算输入流的etag:
 
-    etag规格参考 http://developer.qiniu.com/docs/v6/api/overview/appendix.html#qiniu-etag
+    etag规格参考 https://developer.qiniu.com/kodo/manual/1231/appendix#3
 
     Args:
         input_stream: 待计算etag的二进制流
@@ -145,7 +146,7 @@ def etag(filePath):
 def entry(bucket, key):
     """计算七牛API中的数据格式:
 
-    entry规格参考 http://developer.qiniu.com/docs/v6/api/reference/data-formats.html
+    entry规格参考 https://developer.qiniu.com/kodo/api/1276/data-format
 
     Args:
         bucket: 待操作的空间名
@@ -158,3 +159,14 @@ def entry(bucket, key):
         return urlsafe_base64_encode('{0}'.format(bucket))
     else:
         return urlsafe_base64_encode('{0}:{1}'.format(bucket, key))
+
+
+def rfc_from_timestamp(timestamp):
+    """将时间戳转换为HTTP RFC格式
+
+    Args:
+        timestamp: 整型Unix时间戳（单位秒）
+    """
+    last_modified_date = datetime.fromtimestamp(timestamp)
+    last_modified_str = last_modified_date.strftime('%a, %d %b %Y %H:%M:%S GMT')
+    return last_modified_str
